@@ -6,6 +6,7 @@ import json
 import signal
 import traceback
 from collections import deque
+from contextlib import nullcontext
 from pathlib import Path
 from typing import Any
 
@@ -130,7 +131,6 @@ def setup_cli():
         case_sensitive=False,
     ),
     is_eager=True,
-    callback=lambda x, y, z: init_cli_logger(z),
 )
 @click.argument("patchflow", nargs=1, required=True)
 @click.argument("opts", nargs=-1, type=click.UNPROCESSED, required=False)
@@ -144,6 +144,7 @@ def setup_cli():
 )
 @click.option("patched_api_key", "--patched_api_key", help="API key to use with the patched.codes service.")
 @click.option("disable_telemetry", "--disable_telemetry", is_flag=True, help="Disable telemetry.", default=False)
+@click.option("debug", "--debug", is_flag=True, help="Enable debug mode.", default=False)
 def cli(
     log: str,
     patchflow: str,
@@ -153,9 +154,12 @@ def cli(
     data_format: str,
     patched_api_key: str | None,
     disable_telemetry: bool,
+    debug: bool,
 ):
     setup_cli()
 
+    init_cli_logger(log)
+
     if "::" in patchflow:
         module_path, _, patchflow_name = patchflow.partition("::")
     else:
@@ -164,7 +168,9 @@ def cli(
 
     possbile_module_paths = deque((module_path,))
 
-    with logger.panel("Initializing Patchwork CLI"):
+    panel = logger.panel("Initializing Patchwork CLI") if debug else nullcontext()
+
+    with panel:
         inputs = {}
         if patched_api_key is not None:
             inputs["patched_api_key"] = patched_api_key
@@ -203,6 +209,9 @@ def cli(
                 logger.error(f"Config path {config} is neither a file nor a directory")
                 exit(1)
 
+        if debug:
+            inputs["debug"] = True
+
         patchflow_class = find_patchflow(possbile_module_paths, patchflow_name)
         if patchflow_class is None:
             logger.error(f"Patchflow {patchflow_name} not found in {possbile_module_paths}")
@@ -219,7 +228,11 @@ def cli(
             # treat --key=value as a key-value pair
             inputs[key] = value
 
-    with logger.panel(f"Patchflow {patchflow} logs") as _:
+    patchflow_panel = nullcontext() if debug else logger.panel(f"Patchflow {patchflow} inputs")
+
+    with patchflow_panel as _:
+        if debug is True:
+            logger.info("DEBUGGING ENABLED. INPUTS WILL BE SHOWN BEFORE EACH STEP BEFORE PROCEEDING TO RUN IT.")
         try:
             patched = PatchedClient(inputs.get("patched_api_key"))
             if not disable_telemetry:
